import { WritableComputedRef } from 'vue-demi';
import { MaybeRef } from '@vueuse/shared';
import { useRoute, useRouter } from 'vue-router';
import { Ref } from 'vue-demi';

interface ReactiveRouteOptions {
    /**
     * Mode to update the router query, ref is also acceptable
     *
     * @default 'replace'
     */
    mode?: MaybeRef<'replace' | 'push'>;
    /**
     * Route instance, use `useRoute()` if not given
     */
    route?: ReturnType<typeof useRoute>;
    /**
     * Router instance, use `useRouter()` if not given
     */
    router?: ReturnType<typeof useRouter>;
}

declare function useRouteHash(defaultValue?: string, { mode, route, router, }?: ReactiveRouteOptions): WritableComputedRef<string>;

declare function useRouteQuery(name: string): Ref<null | string | string[]>;
declare function useRouteQuery<T extends null | string | string[] = null | string | string[]>(name: string, defaultValue?: T, options?: ReactiveRouteOptions): Ref<T>;

export { useRouteHash, useRouteQuery };
